
********************************************************************
*********************************************************************
*Main Text: Baseline Regressions
*********************************************************************
**********************************************
*table 1 (Impact of Crusader Mobilization on Duration of Rule)
use baseline.dta, clear

reg meanduration y700-y1400 sum12001100-sum12001400, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sum12001100-sum12001400 latitude1200 agsuitmean1200 area1200 TRI, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sum12001100-sum12001400 latitude1200 agsuitmean1200 area1200 TRI carolingian1200 Carol_TRI, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sum12001100-sum12001400 latitude1200 agsuitmean1200 area1200 TRI carolingian1200 Carol_TRI citycount_1200bndry cathcount_1200bndry , nocons robust cluster(owner_id) 
                                       
**********************************************
*Rise of Cities Estimations
***********************************************
*table 2 (Impact of Crusader Mobilization on Urbanization)
use cities.dta, clear

reg urbanpop y1000-y1800 crusadeX1200-crusadeX1800 entityid_12001-entityid_120024, noconst robust cluster(cityid)

reg urbanpop y1000-y1800 crusadeX1200-crusadeX1800 latitude agric_suit TRI entityid_12001-entityid_120024, noconst robust cluster(cityid)

reg urbanpop y1000-y1800 crusadeX1200-crusadeX1800 latitude agric_suit TRI carolingian Carol_TRI entityid_12001-entityid_120024, noconst robust cluster(cityid)
                                       
****************************************************
*City Autonomy Estimations from Stasavage(2014)
****************************************************
*table 3 (Impact of Crusader Mobilization on Autonomy and Years of Independence)
use autonomy.dta, clear

reg autonomous y1000-y1800 crusadeX1200-crusadeX1800 popi   countrydum1-countrydum9, noconst cluster(cityn)

reg autonomous y1000-y1800 crusadeX1200-crusadeX1800 popi port bishop roman riverine latitude longitude countrydum1-countrydum9, noconst cluster(cityn)

reg yearsindep y1000-y1800 crusadeX1200-crusadeX1800 popi countrydum1-countrydum9, noconst cluster(cityn)

reg yearsindep y1000-y1800 crusadeX1200-crusadeX1800 popi port bishop roman riverine latitude longitude countrydum1-countrydum9, noconst cluster(cityn)

**********************************************
*Urbanization within France, 1500 CE
**********************************************
*Table 4 (Impact of Crusade Mobilization on Urbanization within France
use france.dta, clear

reg sum_yr1500 count_crusades, robust

reg sum_yr1500 count_crusades areakm agricsuit, robust

reg sum_yr1500 count_crusades areakm agricsuit sum_yr1000, robust

*******************************************************
*Parliament Estimation
*******************************************************
*Figure 3:
use parl_partial.dta, clear
reg num_parl crusadecount agsuitmean1200 citycount_1200bndry, robust cluster(owner_id)
gen pos=6
avplot crusadecount, name(a, replace) mlabel(short_name)  ytitle("Parliament(1100-1400CE)", size(medium)) ylabel(,labsize(small)) xtitle("Crusaders|Controls", ///
size(medium)) scheme(s1mono) mlabv(pos)
avplot citycount, name(b, replace) mlabel(short_name) ytitle("Parliament(1100-1400CE)", size(medium)) ylabel(,labsize(small)) xtitle("Urban|Controls", ///
size(medium)) scheme(s1mono) mlabv(pos)
avplot agsuitmean, name(c, replace) mlabel(short_name) ytitle("Parliament(1100-1400CE)", size(medium)) ylabel(,labsize(small)) xtitle("Agric|Controls", ///
size(medium)) scheme(s1mono) mlabv(pos)
graph combine a b c, name(partial_plots_parliament, replace) graphregion(color(white) lwidth(large))
********************************************************************
*Karaman and Pamuk Revenue Estimation
********************************************************************
*Figure 4:
use revenue_partial, clear
reg totalrev_combined fourwaves1200 agsuitmean1200 citycount1000, robust
gen pos=6
avplot fourwaves1200, name(partial_revenue_a, replace) mlabel(short_name) ///
 scheme(s1mono) ///
ytitle("Total Revenue", size(medium)) ///
ylabel(,labsize(small)) xtitle("Crusaders|Controls", size(medium)) mlabv(pos)
avplot citycount1000, name(partial_revenue_b, replace) mlabel(short_name) ///
scheme(s1mono) ///
ytitle("Total Revenue", size(medium)) ///
ylabel(,labsize(small)) xtitle("Urban|Controls", size(medium)) mlabv(pos)
avplot agsuitmean1200, name(partial_revenue_c, replace) mlabel(short_name) ///
scheme(s1mono) ///
ytitle("Total Revenue", size(medium)) ///
ylabel(,labsize(small)) xtitle("Agric|Controls", size(medium)) mlabv(pos)
graph combine partial_revenue_a partial_revenue_b partial_revenue_c, name(partial_plots_revenue_all, replace) graphregion(color(white) lwidth(large))
***************************************************************
*Figure 5-see fig5.do
***************************************************************
***********************************************************
*Figure 6 (Partial regression plots of the conditional effects of crusader mobilization and province area on French provincial assembly meeting frequency)
***********************************************
use france_graph.dta, clear
gen pos=6
reg freq first4 logarea if name!="bourgogne" & name!="poitou", robust
avplot first4, mlabel(name) ytitle(Frequency) xtitle(Crusader|Log Area) scheme(s1mono) mlabv(pos)
graph save temp1,replace
avplot logarea, mlabel(name) ytitle(Frequency) xtitle(Log Area|Crusader) scheme(s1mono) mlabv(pos)
graph save temp2, replace
graph combine temp1.gph temp2.gph, name(partial_plots_france, replace) graphregion(color(white) lwidth(large))
************************************************************
*************************************************************
*************************************************************
*Appendix
*************************************************************
*************************************************************
*************************************************************
*Table 1 summary statistics: Mean Duration
***************************************************************
use baseline.dta, clear
summarize meanduration sum12001200 latitude1200 area1200 agsuitmean1200 TRI citycount_1200bndry cathcount_1200bndry carolingian1200
************************************************************
*Table 2 summary statistics: City Population
**********************************************************
use cities.dta, clear
summarize urbanpop crusadeX1200 latitude agric_suit TRI carolingian 
***********************************************************
*Table 3 summary statistics: Urban Autonomy
**********************************************************
use autonomy.dta, clear
estpost summarize autonomous yearsindep crusadeX1200 popi port bishop roman riverine latitude longitude 
**************************************************************
*Table 4: Crusader States vs. non-Crusader States on Duration of Rule (Outlier Analysis)
*****************************************************************
use baseline.dta, clear

reg meanduration y700-y1400 sum12001100-sum12001400 latitude1200 area1200 agsuitmean1200 TRI Carol_TRI citycount_1200bndry cathcount_1200bndry carolingian1200, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sum12001100-sum12001400 latitude1200 area1200 agsuitmean1200 TRI Carol_TRI citycount_1200bndry cathcount_1200bndry carolingian1200 if owner_id!=1423 & owner_id!=2160 & owner_id!=1225, nocons robust cluster(owner_id) 
  
******************************************************************************
*Table 5: Impact of Crusader Mobilization on Duration of Rule (Flexible Boundaries)
**************************************************************************************
use flexible.dta, clear

reg meanduration y700-y1400 sumwaves1100-sumwaves1400, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sumwaves1100-sumwaves1400 latitude areakm2 agsuitmean TRI, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sumwaves1100-sumwaves1400 latitude areakm2 agsuitmean TRI percentcarolingian Carol_TRI, nocons robust cluster(owner_id) 

reg meanduration y700-y1400 sumwaves1100-sumwaves1400 latitude areakm2 agsuitmean TRI percentcarolingian Carol_TRI citycount cathedralcount percentcarolingian, nocons robust cluster(owner_id) 

********************************************************************************************************
*Figure 1: Partial regression plots of the conditional effects of crusader mobilization on centuries of parliament existence (Flexible Boundaries)
******************************************************************************************************
use partial_parliament_flex.dta, replace
reg num_parl crusadecount agsuitmeanmax citycountmax, robust cluster(owner_id)
gen pos=6
avplot crusadecount, name(a, replace) mlabel(short)  ytitle("Parliament(1100-1400CE)", size(medium)) ylabel(,labsize(small)) xtitle("Crusaders|Controls", ///
size(medium)) scheme(s1mono) mlabv(pos)
avplot citycountmax, name(b, replace) mlabel(short) ytitle("Parliament(1100-1400CE)", size(medium)) ylabel(,labsize(small)) xtitle("Urban|Controls", ///
size(medium)) scheme(s1mono) mlabv(pos)
avplot agsuitmeanmax, name(c, replace) mlabel(short) ytitle("Parliament(1100-1400CE)", size(medium)) ylabel(,labsize(small)) xtitle("Agric|Controls", ///
size(medium)) scheme(s1mono) mlabv(pos)
graph combine a b c, name(partial_parliament_flex, replace) graphregion(color(white) lwidth(large))
************************************************************************
*Figure 2: Impact of Crusader Mobilization on Revenue (Flexible Boundaries)
**************************************************************************
use revenue_flexible.dta, clear
reg totalrev15001800 fourwaves1200 agsuitmean1200 citycount1000, robust
gen pos=6
avplot fourwaves1200, name(partial_revenue_a, replace) mlabel(short_name) ///
 scheme(s1mono) ///
ytitle("Total Revenue", size(medium)) ///
ylabel(,labsize(small)) xtitle("Crusaders|Controls", size(medium)) mlabv(pos)

avplot citycount1000, name(partial_revenue_b, replace) mlabel(short_name) ///
scheme(s1mono) ///
ytitle("Total Revenue", size(medium)) ///
ylabel(,labsize(small)) xtitle("Urban|Controls", size(medium)) mlabv(pos)

avplot agsuitmean1200, name(partial_revenue_c, replace) mlabel(short_name) ///
scheme(s1mono) ///
ytitle("Total Revenue", size(medium)) ///
ylabel(,labsize(small)) xtitle("Agric|Controls", size(medium)) mlabv(pos)

graph combine partial_revenue_a partial_revenue_b partial_revenue_c, name(partial_plots_revenue_flexible, replace) graphregion(color(white) lwidth(large))






